@@ -17,24 +17,12 @@
 # along with Fail2Ban; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-__author__ = "Cyril Jaquier, Arturo 'Buanzo' Busleiman"
-__copyright__ = "Copyright (c) 2009 Cyril Jaquier"
+__author__ = "Cyril Jaquier, Arturo 'Buanzo' Busleiman, Yaroslav Halchenko"
 __license__ = "GPL"
 
 
 def formatExceptionInfo():
-	""" Author: Arturo 'Buanzo' Busleiman """
+	""" Consistently format exception information """
 	import sys
 	cla, exc = sys.exc_info()[:2]
-	excName = cla.__name__
-	try:
-		excArgs = exc.__dict__["args"]
-		# Assure that we always return a string, without unneeded
-		# 'decorations' with python <= 2.5 where args would be a tuple
-		if isinstance(excArgs, tuple) and len(excArgs) == 1:
-			excArgs = excArgs[0]
-		excArgs = str(excArgs)
-	except KeyError:
-		# And always provide a string output
-		excArgs = str(exc)
-	return (excName, excArgs)
+	return (cla.__name__, str(exc))
